var classplstream =
[
    [ "plstream", "classplstream.html#a8b959ea9bc82dc2ed5c26d2b14a3b88b", null ],
    [ "plstream", "classplstream.html#a0b65ab13455c59f457f3037eb08cbbe1", null ],
    [ "plstream", "classplstream.html#a509a2effd7cc490125bdfb212164e3df", null ],
    [ "plstream", "classplstream.html#a5b82b6d85045af7a99d338db2636aaad", null ],
    [ "plstream", "classplstream.html#a5c83b9ac15f9bb2163925a221c455e96", null ],
    [ "plstream", "classplstream.html#a2d7490c793125bf86c71a517de5bfc12", null ],
    [ "plstream", "classplstream.html#a56a016565198f4cd1c04a6a1b860234c", null ],
    [ "~plstream", "classplstream.html#a5af59482d375dff51d99f49715d5888a", null ],
    [ "adv", "classplstream.html#ab7f5e5c91c441fc52d4e19289780a2b2", null ],
    [ "Alloc2dGrid", "classplstream.html#aa140f00e5046b418d58a626234f1f263", null ],
    [ "arc", "classplstream.html#a2df216bc3bcfb93557a580f9db97d31c", null ],
    [ "axes", "classplstream.html#aae9c3ed421ec29c56c6a1ea0767ea0d4", null ],
    [ "bin", "classplstream.html#aad778bc5fa73b64be84fa815ef5e755c", null ],
    [ "bop", "classplstream.html#ae06d098b31cd579cd41d81f5db1c6be8", null ],
    [ "box", "classplstream.html#ac61565fc7b11af20d18b49a085af1071", null ],
    [ "box3", "classplstream.html#a98036fa884d2a01a13ba3b409582827d", null ],
    [ "btime", "classplstream.html#a8d930554eddade61d8cee0fa029bae9f", null ],
    [ "calc_world", "classplstream.html#ad96c824f1136684bae32c89d1d49e67c", null ],
    [ "clear", "classplstream.html#af542aefb8cfea11f5e747e13311b5ce4", null ],
    [ "ClearOpts", "classplstream.html#a3921c12c03ad654e354bbba07a6c57eb", null ],
    [ "cmd", "classplstream.html#a0aed09ebde7556077e59ecba2af1b2a8", null ],
    [ "col", "classplstream.html#a814d3ed5c7a45bdc5359e252bee5b6c7", null ],
    [ "col0", "classplstream.html#a6cde7180bbc3ab9e10d3a4f4439bd785", null ],
    [ "col1", "classplstream.html#a943581cf5af193483948da880ee58f2e", null ],
    [ "colorbar", "classplstream.html#a9364f32b836a2b176a7f05101238f501", null ],
    [ "configtime", "classplstream.html#a46ecf82c5d6c6da684f6143c650b698c", null ],
    [ "cont", "classplstream.html#abebc7506ac6888b4956464b471a3df89", null ],
    [ "cpstrm", "classplstream.html#ab24f6d2d81f77b70cc8c2ca34c38973c", null ],
    [ "ctime", "classplstream.html#a60956f9ea224e1007f85ef218166fc4f", null ],
    [ "did2pc", "classplstream.html#a391ce788e59848110b661569d4b1e2c4", null ],
    [ "dip2dc", "classplstream.html#a97f3fef8272ba076824a93fd038f9b92", null ],
    [ "env", "classplstream.html#a8446dbff6d616d216f637b68296ecb47", null ],
    [ "env0", "classplstream.html#a2660b00746e4161fd9fe770479f35dbd", null ],
    [ "eop", "classplstream.html#adb01aa4adbe476a2cee8634efcebc487", null ],
    [ "errx", "classplstream.html#af2040e913a13180c412b5ddd5fa4a1c9", null ],
    [ "erry", "classplstream.html#a9fa9b451ff40e7c76a5b20d670d84e5f", null ],
    [ "f2eval", "classplstream.html#afae26b15f7027b182570acab74106a76", null ],
    [ "f2eval2", "classplstream.html#af9e0e79286018720e4624bd0b8812899", null ],
    [ "f2evalr", "classplstream.html#aeda26afa918fea9cdfeca1eb882675d3", null ],
    [ "famadv", "classplstream.html#ae3c8cb7cf780a38b8f4d15b7fad6e885", null ],
    [ "fcont", "classplstream.html#abad845e9b003856c76f91a0a0416ab55", null ],
    [ "fill", "classplstream.html#a11207900db18a5701868fdce0442856a", null ],
    [ "fill3", "classplstream.html#a812d3b67f97f4c7cc217283394959ae0", null ],
    [ "FindCommand", "classplstream.html#a22019eeeb9e29aa70395bdb4cce74fa9", null ],
    [ "FindName", "classplstream.html#a1f85dfff7f5b9885b61dba6034ee2927", null ],
    [ "flush", "classplstream.html#af125e9b6a1353ae094f37d585772388f", null ],
    [ "font", "classplstream.html#a914529e3bbfa8152601ef5dd1128f76d", null ],
    [ "fontld", "classplstream.html#a95cefa0ee7ebe5df2dba2b07f508d78f", null ],
    [ "Free2dGrid", "classplstream.html#a5dd0b25c877c8c6ed472ce987489cdf8", null ],
    [ "fshade", "classplstream.html#a389c321002d05e5f79eade2253ec2622", null ],
    [ "gchr", "classplstream.html#ae7efc7ade952636c6abe4aa0f7d4546a", null ],
    [ "gcmap1_range", "classplstream.html#ad33d6f819a27a64e0f78458bcee80064", null ],
    [ "gcol0", "classplstream.html#aba4cd52aa9af674333751cfd4c3e1f0e", null ],
    [ "gcol0a", "classplstream.html#ae03112e488b0c59a977e82d0393b8432", null ],
    [ "gcolbg", "classplstream.html#a3c25068052fb61248d1628384fd742ec", null ],
    [ "gcolbga", "classplstream.html#a6f104110f4ec0c354ef1d936b0191cc7", null ],
    [ "gcompression", "classplstream.html#af31ea9050a284ecb3ee79f5a789008bf", null ],
    [ "gdev", "classplstream.html#a85190181cec5e69ef8c45a50d6b0cbf0", null ],
    [ "gdidev", "classplstream.html#a97bd87e7d140e103e6788c5469e7c429", null ],
    [ "gdiori", "classplstream.html#a33846a59b77a7ec421632667fb4a6077", null ],
    [ "gdiplt", "classplstream.html#a115a82090b4005cba6c4603e3db014fe", null ],
    [ "gesc", "classplstream.html#a4cdd16f2533213fef5cd5d18358af469", null ],
    [ "GetCursor", "classplstream.html#a1ec36e604b750ef5b72a562b31a001f6", null ],
    [ "GetFlt", "classplstream.html#a54d547e04f4085121c578812f1d08d73", null ],
    [ "GetInt", "classplstream.html#a4209524d70561e0054aa26e5b72ec015", null ],
    [ "GetName", "classplstream.html#a873c02ff3dcaa3b56633f9eeeee92b9e", null ],
    [ "gfam", "classplstream.html#a61a18d3cdbcbfad10cb2ced205eae617", null ],
    [ "gfci", "classplstream.html#a96589d5dc58d4a7b63cc9fc910150440", null ],
    [ "gfile", "classplstream.html#ab8862567a9344df489af0c51ebd4ab1f", null ],
    [ "gFileDevs", "classplstream.html#a7b9ec1864a7a454798b2d0e994882669", null ],
    [ "gfnam", "classplstream.html#a420b0cbe7c028e24a8508b839ce4f2d0", null ],
    [ "gfont", "classplstream.html#a3d928d926a52599f434642f294961a39", null ],
    [ "glevel", "classplstream.html#ac6f30d556bf27fc3a4f572808cad2535", null ],
    [ "gpage", "classplstream.html#af818bf6334ccc57869c1c5f73a416b23", null ],
    [ "gra", "classplstream.html#a4551fd19d5f4d061bf82a1444ba5c4f4", null ],
    [ "gradient", "classplstream.html#a5c09f493eec498254acb351baab2ef4a", null ],
    [ "griddata", "classplstream.html#a2463e096bfd2fe60b6dd319ef864ffe3", null ],
    [ "gspa", "classplstream.html#a39425564833b970cfb7987060afd94b8", null ],
    [ "gver", "classplstream.html#ade99a4b58c7604335b8baeda1b523c8e", null ],
    [ "gvpd", "classplstream.html#af535642162f734a6f85c4e228dc95df3", null ],
    [ "gvpw", "classplstream.html#a6d6bf3dc926030de4a2b44844af52ab3", null ],
    [ "gxax", "classplstream.html#aaf7d4d814315a499c635bdc14fe7535e", null ],
    [ "gyax", "classplstream.html#af1032c66cea9f4c8137539eb6f0958ea", null ],
    [ "gzax", "classplstream.html#a8e9997fb8b145695d4addef62ea90f71", null ],
    [ "hist", "classplstream.html#a04852ccad48362688647600b24e01cd9", null ],
    [ "hlsrgb", "classplstream.html#ab4be85ad0d45692332ab2bb12dc75dc6", null ],
    [ "image", "classplstream.html#ac989af8edc268809f0356dcdab357d52", null ],
    [ "imagefr", "classplstream.html#ace2be515c97321c1e73da0b058b249c6", null ],
    [ "init", "classplstream.html#ab6fae273970fc2ea6be2b806959df986", null ],
    [ "join", "classplstream.html#a197265e0119b7d0b3ed0a72caac1b29d", null ],
    [ "lab", "classplstream.html#ab077a5655c97d49056ac8cc6094beb4e", null ],
    [ "legend", "classplstream.html#a27e76f10be0e1c2382e1664781513eee", null ],
    [ "lightsource", "classplstream.html#ae129dd5f46b40e6d0b3462633027e8ff", null ],
    [ "line", "classplstream.html#ab94015dfd576f331c581d6389368d013", null ],
    [ "line3", "classplstream.html#a2e15a0c1823c1c405353603ed7311ce4", null ],
    [ "lsty", "classplstream.html#a4a571952c811953cba099f45bcbe3eed", null ],
    [ "map", "classplstream.html#a9eae44d093132b9390ffd3213f8c6d69", null ],
    [ "mapfill", "classplstream.html#a6ea88facf649127e2f2b702d7e6f50c0", null ],
    [ "mapline", "classplstream.html#af4a1e0441e430fb6a02b704c589c1d08", null ],
    [ "mapstring", "classplstream.html#a875a25f30336429590bd4cc5831e4eba", null ],
    [ "maptex", "classplstream.html#ae29d90ca5c450891d4f9e01023775764", null ],
    [ "MergeOpts", "classplstream.html#ab1de3640ae79d11369cb47fb89eb5faa", null ],
    [ "meridians", "classplstream.html#a7c73766685da5f70691167e6ea3870d5", null ],
    [ "mesh", "classplstream.html#aef940236ed0723c5d3342f1f443e1584", null ],
    [ "meshc", "classplstream.html#a6057782840bab5084eb82bbd06e44762", null ],
    [ "MinMax2dGrid", "classplstream.html#ac7590a37329e76bc1877a9b6a624d8af", null ],
    [ "mtex", "classplstream.html#a275d45c168a620a9636c80039507db6a", null ],
    [ "mtex3", "classplstream.html#a44b5a3743d67214ea3f81f198faadd9e", null ],
    [ "operator=", "classplstream.html#a2dbfc7548479908d27dab94893aacae1", null ],
    [ "OptUsage", "classplstream.html#af54356617be65cdf161918e3430321df", null ],
    [ "parseopts", "classplstream.html#a83fb619e15efeb67b76b6ff4737a750b", null ],
    [ "pat", "classplstream.html#a53df0e65b853f901c0ece2bc910ecb93", null ],
    [ "path", "classplstream.html#ac67651bdb28405cfa204c342901aa5c1", null ],
    [ "plot3d", "classplstream.html#a41ca966d482620a54c58d57365283abe", null ],
    [ "plot3dc", "classplstream.html#af1b96858211dce025c64fb0b5a84d7fe", null ],
    [ "plot3dcl", "classplstream.html#ac8749d7e1682f59e380c78923ad6c49f", null ],
    [ "poin", "classplstream.html#a9f55e53eb2a0174e53dd4f3d3856ef12", null ],
    [ "poin3", "classplstream.html#a78128eb2e5a20aff41e9450d6b1db5c1", null ],
    [ "poly3", "classplstream.html#acfba92fa1b426a04592e3517cf4dff95", null ],
    [ "prec", "classplstream.html#a7a117b27a8c4d9edba33224e92939591", null ],
    [ "psty", "classplstream.html#a56ddd5bba6e2e044225c98692d6b5d36", null ],
    [ "ptex", "classplstream.html#ab06ceccd61a62e4d0a5e11452094cfdd", null ],
    [ "ptex3", "classplstream.html#a7df80843160f8c2fbb28eb6aba76d10c", null ],
    [ "randd", "classplstream.html#a548b5563e4a23301ca3ea443669d265e", null ],
    [ "replot", "classplstream.html#a2c5b31d08823adc08013731a3e700d66", null ],
    [ "ResetOpts", "classplstream.html#afedc5ae79894b5eb0a61009b5abe2a48", null ],
    [ "rgbhls", "classplstream.html#ab20d34ab36c257ca5358218e3000fb8f", null ],
    [ "sbopH", "classplstream.html#ad54388eaf0dfab68f38f708b88e436d4", null ],
    [ "schr", "classplstream.html#a1790d85af2621126c501af4a80c163e5", null ],
    [ "scmap0", "classplstream.html#abb70c6d7e6dd9b3e2d18de96495870be", null ],
    [ "scmap0a", "classplstream.html#a19d3289f22ecd8ea9f20cc5a5f317c45", null ],
    [ "scmap0n", "classplstream.html#a979efc8c39e9c850cb64602dcbbda2cf", null ],
    [ "scmap1", "classplstream.html#a1a82e1b71fa2195f6f5cfb2ccf5b7802", null ],
    [ "scmap1_range", "classplstream.html#ac82b4378ed491f20571ff42987ba3325", null ],
    [ "scmap1a", "classplstream.html#a1f0afae15c66fb06e3aabd7901519502", null ],
    [ "scmap1l", "classplstream.html#a6ce468b17faf6fefeb1e22921a230be0", null ],
    [ "scmap1la", "classplstream.html#ad7b1d5173bb09c358411e07b5c64b133", null ],
    [ "scmap1n", "classplstream.html#a6d85337661f8b9797d2ee75758d87179", null ],
    [ "scol0", "classplstream.html#a3b8ae477ba529bd6963919571c0be9b1", null ],
    [ "scol0a", "classplstream.html#ab2ba1762a0aa99df239027f52f2ac6fb", null ],
    [ "scolbg", "classplstream.html#a4145dd0086fab6650de299715e041405", null ],
    [ "scolbga", "classplstream.html#af54095d104d18bb78b974d6e0aecc54b", null ],
    [ "scolor", "classplstream.html#a84ef4d99ad19875b8cdd8bd981da11c7", null ],
    [ "scompression", "classplstream.html#a36776b135f2944457d425137e5cf74b6", null ],
    [ "sdev", "classplstream.html#a7d20d33e51027b1f9f51741e3077118a", null ],
    [ "sdevdata", "classplstream.html#a1cf1d9758ff57dc3e28edcad96c14b86", null ],
    [ "sdidev", "classplstream.html#ae543f281616cc859ef0df3dcbd69f596", null ],
    [ "sdimap", "classplstream.html#a1a602824a9006c3f738604a4896157b6", null ],
    [ "sdiori", "classplstream.html#a78c74852bf35b9702a6dcd93d42234d4", null ],
    [ "sdiplt", "classplstream.html#a67206024db76c7db01e0396c01c91d61", null ],
    [ "sdiplz", "classplstream.html#a742336c964e9f3efb3c006bc22ae20e7", null ],
    [ "seed", "classplstream.html#aaa76c93921e7213be51e49034630f5d6", null ],
    [ "seopH", "classplstream.html#a3005e9b4e1d55dd53751c3acc15b35df", null ],
    [ "sError", "classplstream.html#aacc4651c069a08e85524c0d6362ec165", null ],
    [ "sesc", "classplstream.html#a8f80ec69dcd0578cfe0297566a516cbf", null ],
    [ "set_stream", "classplstream.html#a287ce967102bd8a48fd4ef10bf3c43a7", null ],
    [ "setcontlabelformat", "classplstream.html#a95fe4d06455d15fb05b78fed6dd6466b", null ],
    [ "setcontlabelparam", "classplstream.html#aac16de4490642f50b540ad952e6aff51", null ],
    [ "setopt", "classplstream.html#a1111f25bd8672650778425691a7f80d9", null ],
    [ "SetOpt", "classplstream.html#a1738c259311b50ebe4ac9dba6be8eda6", null ],
    [ "SetUsage", "classplstream.html#afbeef4bb6c805141aabe4406ae7a46ba", null ],
    [ "sexit", "classplstream.html#aa0e9f6f70b518e862d2866f773d1aca9", null ],
    [ "sfam", "classplstream.html#a541c86156690454732d3c6c96ddb1d34", null ],
    [ "sfci", "classplstream.html#aec1b69c6fa483ced8b4120cadfd504bf", null ],
    [ "sfile", "classplstream.html#ae1b9314fadcd56f2ace95245ed8e96ba", null ],
    [ "sfnam", "classplstream.html#a3a569eb21b15d9bcc289baafb0c4febf", null ],
    [ "sfont", "classplstream.html#a91fb74d3049cfc5aee44aa4c79d91fa5", null ],
    [ "shade", "classplstream.html#a4574ee31c09ee2b6adf7c7e56d564d6a", null ],
    [ "shade", "classplstream.html#a304a4d2f030a260d1eda23146f071a00", null ],
    [ "shades", "classplstream.html#adde882d5199742454da45d18420c601a", null ],
    [ "sKeyEH", "classplstream.html#a98fe43bcaec074c698e7baa82d1af422", null ],
    [ "slabelfunc", "classplstream.html#aa0b69eeeeefa7f4a71184001f8b946c0", null ],
    [ "smaj", "classplstream.html#ac4af1ef0006205c87c77f075fa29d520", null ],
    [ "smem", "classplstream.html#a8dc592daa30e3399119275dcc4b3a7a6", null ],
    [ "smema", "classplstream.html#a1f1addb739a98b11e15827367c9dce78", null ],
    [ "smin", "classplstream.html#a0fd06540f1adbd4cf74108daa1473e7e", null ],
    [ "sori", "classplstream.html#acb691b9dd19cc2585978de1bd1125835", null ],
    [ "spage", "classplstream.html#a76eb06a46d097f6f6d7c3d5b63fd0fee", null ],
    [ "spal0", "classplstream.html#a04f0cb933006bf6700acf8bcab2f2658", null ],
    [ "spal1", "classplstream.html#a855bdc0dc9a8d6cbfa79c602d34b8346", null ],
    [ "spause", "classplstream.html#adced3758bc250a1cb2ce22eceef005d2", null ],
    [ "sstrm", "classplstream.html#a126cddeb3f33eb23e49399b2422faaf6", null ],
    [ "ssub", "classplstream.html#aa154ccc662e42b8914d1ccb5c1b79025", null ],
    [ "ssym", "classplstream.html#a897b309e307033532093edabb14d3d7c", null ],
    [ "star", "classplstream.html#a3e4314ad8f9e2c52d230562a51b001a8", null ],
    [ "start", "classplstream.html#af9ae28094f4dc1630bf8cdfdf834f374", null ],
    [ "Static2dGrid", "classplstream.html#a46fbb635ebc7f9dd439c3f17ad354210", null ],
    [ "stransform", "classplstream.html#a1d5189f44e2c78db6f39a1ab28ad6ea6", null ],
    [ "string", "classplstream.html#a67cf3bbe5ada1e44014bb669845ccc9d", null ],
    [ "string3", "classplstream.html#ae1a113fa6fd26bf4d6d712f545f0eb3d", null ],
    [ "stripa", "classplstream.html#a8f2e30bdaaa11336b45432a2169b3027", null ],
    [ "stripc", "classplstream.html#acdee31e840663387b6670597f658d533", null ],
    [ "stripd", "classplstream.html#a5c75ee6c39722e68ce3d4353ea8d8c3e", null ],
    [ "styl", "classplstream.html#a99bfa28534e367d7231b6521e1e2261c", null ],
    [ "surf3d", "classplstream.html#ad62c88c23bedfd3ecbf63ba2d9e1279c", null ],
    [ "surf3dl", "classplstream.html#adb6431e447f249687a3b76a08e58e27f", null ],
    [ "svect", "classplstream.html#abb015cff1f650cc88414a2eb8eb45584", null ],
    [ "svpa", "classplstream.html#a26e8905fbe594ff2f64949918972fbf6", null ],
    [ "sxax", "classplstream.html#a8844b2f8a416aca783b7da4b65066031", null ],
    [ "sxwin", "classplstream.html#a752fa6e2837a2fea7015cc95f67d3e62", null ],
    [ "syax", "classplstream.html#ae21d030a55938f13e5603e5531006f45", null ],
    [ "sym", "classplstream.html#a6c213bdd698022e6a446c980fc510bb1", null ],
    [ "szax", "classplstream.html#aa1deeb534cd28668cbf878782d205119", null ],
    [ "text", "classplstream.html#a3cdd797ab78f23697ba7a349dc0f0e74", null ],
    [ "timefmt", "classplstream.html#a748813a8db4e3cc186b5d9fae8538c39", null ],
    [ "translatecursor", "classplstream.html#a993f6a90006f36dd0d4b5a80e87fd2a8", null ],
    [ "vasp", "classplstream.html#a18f26cc66fed4937f5bfc6267672b4f3", null ],
    [ "vect", "classplstream.html#a67d0589d500925101847214a8c1919dd", null ],
    [ "vpas", "classplstream.html#a99cca3086170b0961ced3f6f64fa3166", null ],
    [ "vpor", "classplstream.html#a558a4a11d26d066c740d69c5acdd1725", null ],
    [ "vsta", "classplstream.html#ae87e48cffe8609c379000f9876f1abba", null ],
    [ "w3d", "classplstream.html#a66f2583f5f748c663508269dd00c1100", null ],
    [ "width", "classplstream.html#a7a993bd850c9dc8d7f3fab51b544c778", null ],
    [ "wind", "classplstream.html#a01d10b709219154e2cd6f7d8920ba95d", null ],
    [ "xormod", "classplstream.html#ab338a30331e3e8fb4254e8599ec9fe42", null ],
    [ "active_streams", "classplstream.html#a40c5a40e609b74ef8b1046da85edf495", null ],
    [ "stream", "classplstream.html#a8842149487ed8a785601f2ecfb66f818", null ]
];